@@ -2,21 +2,21 @@
 #######################################################################
 """Product class for the Zope 3 based quota package
 
-$Id: histogram.py 49752 2008-01-27 20:25:18Z cray $
+$Id: histogram.py 49790 2008-01-29 22:41:24Z cray $
 """
 __author__  = "Andrey Orlov"
 __license__ = "GPL"
 __version__ = "$Revision: 12897 $"
 
 from zope.proxy import removeAllProxies
-from ng.app.quota.interfaces import IQuotaAnnotation
+from ng.app.quota.interfaces import IQuota
 
 class Histogram(object) :
 
     def __init__(self,context,request) :
         super(Histogram,self).__init__(context,request)
 
-        quota = removeAllProxies(IQuotaAnnotation(self.context))
+        quota = removeAllProxies(IQuota(self.context))
         
         res = quota.osz.values()
         
