@@ -2,7 +2,7 @@
 #######################################################################
 """Interfaces for the Zope 3 based Quota package
 
-$Id: interfaces.py 49752 2008-01-27 20:25:18Z cray $
+$Id: interfaces.py 49790 2008-01-29 22:41:24Z cray $
 """
 
 __author__  = "Andrey Orlov, 2008"
@@ -80,13 +80,20 @@ class IQuotaHandle(Interface) :
     def handleModified(ob): 
         pass
  
-    def handleRemoved( ob): 
+    def handleRemoved(ob): 
         pass
 
     def reset(ob) :
         pass
+        
 
-class IQuotaAnnotable(Interface) :
+class IQuotaAvailable(Interface) :
+    pass
+
+class IQuotaAnnotable(IQuotaAvailable) :
+    pass
+
+class IQuotaUtilitable(IQuotaAvailable) :
     pass
 
 class IQuota(IQuotaData, IQuotaStat, IQuotaHandle, IQuotaAnnotable) :
@@ -98,8 +105,23 @@ class IQuotaUtility(IQuota) :
 class IQuotaAnnotation(IQuota) :
     """ Quota Annotation """
     
-class IQuotaAll(IQuota) :
-    """ Proxy for all Quota Utilities """
+class IQuotaAll(Interface) :
+    """ Enumerator for all Quota Utilities """
+
+    def next() :
+        pass 
+
+    def __iter__() :
+        pass
+
+class IQuotaUtilities(Interface) :
+    """ Enumerator for all Quota Utilities """
+
+    def next() :
+        pass 
+
+    def __iter__() :
+        pass
 
 class IQuotaContained(IContained) :                
     __parent__ = Field(
