@@ -2,7 +2,7 @@
 #######################################################################
 """Product class for the Zope 3 based quota package
 
-$Id: quota.py 49752 2008-01-27 20:25:18Z cray $
+$Id: quota.py 49790 2008-01-29 22:41:24Z cray $
 """
 __author__  = "Andrey Orlov"
 __license__ = "GPL"
@@ -50,7 +50,6 @@ class Quota(Contained,Persistent):
         self.max = 0
             
     def handleAdded(self, object): 
-        print "handleAdded:",self.__name__, object.__name__
         if self.stat :
             size = IRecordSize(object).size
             try :
@@ -76,13 +75,14 @@ class Quota(Contained,Persistent):
                 key = zapi.getUtility(IIntIds, context=self).getId(object)
             except ComponentLookupError,msg:
                 print "QuotaModifiedFailed:",msg
+            except KeyError,msg :
+                print "QuotaModifiedFailed (keyerror):",msg
             else :
                 try :
                     oldsize = self.osz[key]
-                except KeyError :
-                    pass            
-                except ComponentLookupError,msg:
-                    print "QuotaAddFailed:",msg
+                except KeyError,msg :
+                    print "Modified Quota Object Unknown",msg  
+                    self.count += 1
                 else :
                     self.size-=oldsize
                     if size < self.max <= oldsize :
@@ -90,11 +90,7 @@ class Quota(Contained,Persistent):
                     if oldsize <= self.min < size :
                         self.min = min(self.osz.values())
 
-                try :
-                    self.osz[zapi.getUtility(IIntIds, context=object).getId(object)] = size
-                except KeyError,msg :
-                    print "Can't find modified object in intid or localindex",msg
-
+                self.osz[key] = size
                 self.size+=size
                 self.min = min(self.min,size)
                 self.max = max(self.max,size)
@@ -110,9 +106,6 @@ class Quota(Contained,Persistent):
     def handleRemoved(self, object): 
         if self.stat :
             size = IRecordSize(object).size
-            self.size-=size
-            self.count -= 1
-            self.average = float(self.size) / max(1,self.count)
     
             try :
                 del self.osz[zapi.getUtility(IIntIds, context=object).getId(object)]
@@ -125,3 +118,7 @@ class Quota(Contained,Persistent):
                     self.max = max(self.osz.values())
                 if self.min >= size :
                     self.min = min(self.osz.values())
+
+                self.size-=size
+                self.count -= 1
+                self.average = float(self.size) / max(1,self.count)
